# coding: utf-8

from __future__ import annotations

import re  # noqa: F401
from datetime import datetime  # noqa: F401
from typing import List, Optional  # noqa: F401

from fastapi_camelcase import CamelModel
from pydantic import AnyUrl, Field  # noqa: F401

from telus_bulk.models.tmf_645.check_service_qualification_item import (
    CheckServiceQualificationItem,
)


def generate_queue_item(
    csq_id, service_qualification_item
) -> CheckServiceQualificationQueueItem:
    """
    Creates the structure for the queue
    """
    return {"csqId": csq_id, "serviceQualificationItem": service_qualification_item}


class CheckServiceQualificationQueueItem(CamelModel):
    """NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).

    Do not edit the class manually.

    CheckServiceQualification - a model defined in OpenAPI

        id: The id of this CheckServiceQualification [Optional].
        href: The href of this CheckServiceQualification [Optional].
        check_service_qualification_date: The check_service_qualification_date of this CheckServiceQualification [Optional].
        description: The description of this CheckServiceQualification [Optional].
        effective_qualification_date: The effective_qualification_date of this CheckServiceQualification [Optional].
        estimated_response_date: The estimated_response_date of this CheckServiceQualification [Optional].
        expected_qualification_date: The expected_qualification_date of this CheckServiceQualification [Optional].
        expiration_date: The expiration_date of this CheckServiceQualification [Optional].
        external_id: The external_id of this CheckServiceQualification [Optional].
        instant_sync_qualification: The instant_sync_qualification of this CheckServiceQualification [Optional].
        provide_alternative: The provide_alternative of this CheckServiceQualification [Optional].
        provide_unavailability_reason: The provide_unavailability_reason of this CheckServiceQualification [Optional].
        qualification_result: The qualification_result of this CheckServiceQualification [Optional].
        related_party: The related_party of this CheckServiceQualification [Optional].
        service_qualification_item: The service_qualification_item of this CheckServiceQualification [Optional].
        state: The state of this CheckServiceQualification [Optional].
        base_type: The base_type of this CheckServiceQualification [Optional].
        schema_location: The schema_location of this CheckServiceQualification [Optional].
        type: The type of this CheckServiceQualification [Optional].
    """

    csq_id: Optional[str] = None
    service_qualification_item: Optional[CheckServiceQualificationItem] = None


CheckServiceQualificationQueueItem.update_forward_refs()



# coding: utf-8

from __future__ import annotations

import re  # noqa: F401
from datetime import date, datetime  # noqa: F401
from typing import Any, Dict, List, Optional  # noqa: F401

from fastapi_camelcase import CamelModel  # noqa: F401
from pydantic import AnyUrl, Field


class Error(CamelModel):
    """NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).

    Do not edit the class manually.

    Error - a model defined in OpenAPI

        code: The code of this Error.
        reason: The reason of this Error.
        message: The message of this Error [Optional].
        status: The status of this Error [Optional].
        reference_error: The reference_error of this Error [Optional].
        base_type: The base_type of this Error [Optional].
        schema_location: The schema_location of this Error [Optional].
        type: The type of this Error [Optional].
    """

    code: str
    reason: str
    message: Optional[str] = None
    status: Optional[str] = None
    reference_error: Optional[AnyUrl] = None
    base_type: Optional[str] = None
    schema_location: Optional[AnyUrl] = None
    type: Optional[str] = Field(default=None, alias='@type')


Error.update_forward_refs()



from typing import Any, Optional

from fastapi_camelcase import CamelModel


class E911Address(CamelModel):
    unit: Optional[Any]
    house_number: Optional[str]
    house_suffix: Optional[Any]
    street_name: Optional[str]
    street_type: Optional[Any]
    street_vector_prefix: Optional[Any]
    street_vector_suffix: Optional[Any]
    municipality: Optional[str]
    province: Optional[str]
    postal_code: Optional[str]
    e911_clli: Optional[str]
    esz_number: Optional[str]



from typing import Any

from fastapi_camelcase import CamelModel
from pydantic import Field


class ReferenceId(CamelModel):
    fms_id: str = Field(..., alias='fmsId')
    loc_building_id: str = Field(..., alias='locBuildingId')
    loc_grp_id: Any = Field(..., alias='locGrpId')


# coding: utf-8

from __future__ import annotations

import re  # noqa: F401
from datetime import date, datetime  # noqa: F401
from typing import Any, Dict, List, Optional  # noqa: F401

from fastapi_camelcase import CamelModel  # noqa: F401
from pydantic import AnyUrl, Field


class ServiceSpecificationRef(CamelModel):
    """NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).

    Do not edit the class manually.

    ServiceSpecificationRef - a model defined in OpenAPI

        id: The id of this ServiceSpecificationRef.
        href: The href of this ServiceSpecificationRef [Optional].
        name: The name of this ServiceSpecificationRef [Optional].
        version: The version of this ServiceSpecificationRef [Optional].
        base_type: The base_type of this ServiceSpecificationRef [Optional].
        schema_location: The schema_location of this ServiceSpecificationRef [Optional].
        type: The type of this ServiceSpecificationRef [Optional].
        referred_type: The referred_type of this ServiceSpecificationRef [Optional].
    """

    id: str
    href: Optional[AnyUrl] = None
    name: Optional[str] = None
    version: Optional[str] = None
    base_type: Optional[str] = None
    schema_location: Optional[AnyUrl] = None
    type: Optional[str] = Field(default=None, alias='@type')
    referred_type: Optional[str] = Field(default=None, alias='@referredType')


ServiceSpecificationRef.update_forward_refs()
